| Package name                                                  | Package hash                                                  | Description                                                                                                                |
| ------------------------------------------------------------- | ------------------------------------------------------------- | -------------------------------------------------------------------------------------------------------------------------- |
| protocol/valory/abci/0.1.0                                    | `bafybeig3dj5jhsowlvg3t73kgobf6xn4nka7rkttakdb2gwsg5bp7rt7q4` | A protocol for ABCI requests and responses.                                                                                |
| connection/valory/abci/0.1.0                                  | `bafybeifpdzwpwntu2qu5qks22elglwozpwpwvihrhgw7sgyjpff7yye3za` | connection to wrap communication with an ABCI server.                                                                      |
| connection/valory/ipfs/0.1.0                                  | `bafybeigr2cipad23aebjpnqtzpgymiwrwgmnior2fk4inbscdnqyl5epla` | A connection responsible for uploading and downloading files from IPFS.                                                    |
| contract/valory/gnosis_safe_proxy_factory/0.1.0               | `bafybeieauenpdblyecnjorei2gbfatvgrxwoucigo6x3lksnhwknhawkqa` | Gnosis Safe proxy factory (GnosisSafeProxyFactory) contract                                                                |
| contract/valory/component_registry/0.1.0                      | `bafybeialw5eaa4v54s7i3sjsuy6d5k624quhxhziqntwq5hnz4g646sb7m` | Component registry contract                                                                                                |
| contract/valory/agent_registry/0.1.0                          | `bafybeibkj4pm6ziqh2fl3xfsjiou4ibnxlipmvmqhgvc7xwpnaddbtxzli` | Agent registry contract                                                                                                    |
| contract/valory/registries_manager/0.1.0                      | `bafybeihtfmbzsjwsz7kmujzc4bofyoxckekbdi643f762tj3fe4witgjqu` | Registries Manager contract                                                                                                |
| contract/valory/service_manager/0.1.0                         | `bafybeidzttjrfn3kfxubr24axouytshsm57sjl2232g2z3wlitk6dl32em` | Service Manager contract                                                                                                   |
| skill/valory/test_ipfs_abci/0.1.0                             | `bafybeiffz4lcj5x5xgu2cubti6chb7ziu3zvy5yog2s3v7thj347bzgkzm` | IPFS e2e testing application.                                                                                              |
| agent/valory/test_ipfs/0.1.0                                  | `bafybeiegu2aespp7twf3ih4o56hydk5xxc26izeqpgaa7zsockmrjkdj3a` | Agent for testing the ABCI connection.                                                                                     |
| contract/valory/service_registry/0.1.0                        | `bafybeiegj2cbtyqkw42q3wlqm2opl43ddnp4snavbyllsokscqrp4icwfu` | Service Registry contract                                                                                                  |
| protocol/valory/tendermint/0.1.0                              | `bafybeicusvezoqlmyt6iqomcbwaz3xkhk2qf3d56q5zprmj3xdxfy64k54` | A protocol for communication between two AEAs to share tendermint configuration details.                                   |
| protocol/valory/ipfs/0.1.0                                    | `bafybeic72ncgqbzoz2guj4p4yjqulid7mv6yroeh65hxznloamoveeg7hq` | A protocol specification for IPFS requests and responses.                                                                  |
| skill/valory/abstract_abci/0.1.0                              | `bafybeigte2l4en4otdp2maaoc3uesqdga5z4sqozrybsmcdp26bgfbcy54` | The abci skill provides a template of an ABCI application.                                                                 |
| contract/valory/gnosis_safe/0.1.0                             | `bafybeie4e3ifwa3ch3rqeouzkzndyscrfidbmj2p4ykzwh4zptvsocxcya` | Gnosis Safe (GnosisSafeL2) contract                                                                                        |
| skill/valory/abstract_round_abci/0.1.0                        | `bafybeigsbglflua5vdwmwmo2rjsogp4anxtpqjbtrcwfivuxjiv6xczpba` | abstract round-based ABCI application                                                                                      |
| contract/valory/multisend/0.1.0                               | `bafybeigjywkl7hydjsrkogob3xebj2ifhqwmfhhxoeyrndzhhxi5u6amey` | MultiSend contract                                                                                                         |
| skill/valory/transaction_settlement_abci/0.1.0                | `bafybeiahvk5lgkpwnaruzr34yp7to4fed7tgoufceerwqhvl57t4blqmiu` | ABCI application for transaction settlement.                                                                               |
| skill/valory/registration_abci/0.1.0                          | `bafybeidc7vaj5rw3rzkd6aj3x7bl7r76kcaklqwat2cg7dlzh4yo6h6hhu` | ABCI application for common apps.                                                                                          |
| skill/valory/reset_pause_abci/0.1.0                           | `bafybeigvfkbdmro6dddejdo5vcimdbp7macbez4ejv2beucm7nrje5oz34` | ABCI application for resetting and pausing app executions.                                                                 |
| skill/valory/termination_abci/0.1.0                           | `bafybeif7y4wcmjc4g5iyjkfedephvqwzgkxnkj3tucu24rqz6fsw267l2e` | Termination skill.                                                                                                         |
| skill/valory/counter/0.1.0                                    | `bafybeibpiu5dpafveelnjcy6aiwhcvgitfrpydqqqbrgpzyzvkvgqu4lxa` | The ABCI Counter application example.                                                                                      |
| skill/valory/counter_client/0.1.0                             | `bafybeiaqdfulxamdshw7fykfkqvkpvjb5bnmhv7ffrjiwdi4ktiulklx6q` | A client for the ABCI counter application.                                                                                 |
| skill/valory/hello_world_abci/0.1.0                           | `bafybeih6ze466tq3g7spjyqnp3fkle2da4z2q72cvswttkolb2l23ipcjy` | Hello World ABCI application.                                                                                              |
| skill/valory/register_reset_abci/0.1.0                        | `bafybeifnmrpfm2uhkxgxsjp5y2opyclsuqxkmd3xrxkpoqrm6zugnk5t2u` | ABCI application for dummy skill that registers and resets                                                                 |
| skill/valory/register_termination_abci/0.1.0                  | `bafybeibq4jneble4zatyvw6ouhajh6uqx5cjhnulhbwvh2kgv27jk5lj7u` | ABCI application for dummy skill that registers and resets                                                                 |
| skill/valory/test_abci/0.1.0                                  | `bafybeifc7qnefyzh7hmnzdujiqnukujfggpps6gpctmz6knvw5y2bbumea` | ABCI application for testing the ABCI connection.                                                                          |
| agent/valory/abstract_abci/0.1.0                              | `bafybeif67mbeiboqt4ow7rvx7pbjdoml7ldiznzewdltzk2kmqwf7an5oa` | The abstract ABCI AEA - for testing purposes only.                                                                         |
| agent/valory/counter/0.1.0                                    | `bafybeidey2hibzqyqgt7tzmqvwfez6gpcrwu6sofnave3ukak6nxyvjnse` | The ABCI Counter example as an AEA                                                                                         |
| agent/valory/counter_client/0.1.0                             | `bafybeihfvoaeh6s7idwqxcfs4fpil4mbtvg6jugpul34p335ziztq4r5pi` | The ABCI Counter example as an AEA                                                                                         |
| agent/valory/hello_world/0.1.0                                | `bafybeigxer6v3ujegedzksb3y3kylxg355jsfj26vh7jrs2ovnmpa4axny` | Hello World ABCI example.                                                                                                  |
| agent/valory/register_reset/0.1.0                             | `bafybeieu5zsv6vdlfvbhzatauh2lqfqsezqehoifvc3elahkgextawbzmm` | Register reset to replicate Tendermint issue.                                                                              |
| agent/valory/register_termination/0.1.0                       | `bafybeibqb2n53ekhkxeqyaxmlznolx4itej7tjibciuktaw6ffvkh2uoxq` | Register terminate to test the termination feature.                                                                        |
| agent/valory/registration_start_up/0.1.0                      | `bafybeihox3g2fy5eukygn7o43zb2nouhbg5kqhzijszhdtjbm3jssyqosq` | Registration start-up ABCI example.                                                                                        |
| agent/valory/test_abci/0.1.0                                  | `bafybeicnctb7deixx2zrhp7n3wuifqhxpeky7v4dpbze5fzkeigrl4qt4y` | Agent for testing the ABCI connection.                                                                                     |
| service/valory/counter/0.1.0                                  | `bafybeihojdpcfsj57c44pegokqd6nyxucsd6qlmi5o4gbhwpcuz55dnw7u` | A set of agents incrementing a counter                                                                                     |
| service/valory/hello_world/0.1.0                              | `bafybeifi5sj65jzcw6z5kxde67pbfcyvr4r2ydwezpnv54y43byil4ngee` | A simple demonstration of a simple ABCI application                                                                        |
| service/valory/register_reset/0.1.0                           | `bafybeiapq3td62eam426fv2mzjxkeueexjr6nzzdmpwaws52xdpjusu2he` | Test and debug tendermint reset mechanism.                                                                                 |
| skill/valory/register_reset_recovery_abci/0.1.0               | `bafybeiccyei5mqfxtsjzuktzwbyxyuvx74pcnbesuyknrrgxay2wzjtuoq` | ABCI application for dummy skill that registers and resets                                                                 |
| agent/valory/register_reset_recovery/0.1.0                    | `bafybeickl6x3ntsvkrqflgh7zhgmdfgb7aituvk2yqka2izy7dgjspby2y` | Agent to showcase hard reset as a recovery mechanism.                                                                      |
| contract/valory/multicall2/0.1.0                              | `bafybeigywp4gpl6lel2bemehbvevpfflnwnpjaq3wnb7o7rjnwzqrlnijq` | The MakerDAO multicall2 contract.                                                                                          |
| protocol/open_aea/signing/1.0.0                               | `bafybeibqlfmikg5hk4phzak6gqzhpkt6akckx7xppbp53mvwt6r73h7tk4` | A protocol for communication between skills and decision maker.                                                            |
| protocol/valory/acn/1.1.0                                     | `bafybeignmc5uh3vgpuckljcj2tgg7hdqyytkm6m5b6v6mxtazdcvubibva` | The protocol used for envelope delivery on the ACN.                                                                        |
| protocol/valory/http/1.0.0                                    | `bafybeifyoio7nlh5zzyn5yz7krkou56l22to3cwg7gw5v5o3vxwklibhty` | A protocol for HTTP requests and responses.                                                                                |
| protocol/valory/ledger_api/1.0.0                              | `bafybeibo4bdtcrxi2suyzldwoetjar6pqfzm6vt5xal22ravkkcvdmtksi` | A protocol for ledger APIs requests and responses.                                                                         |
| protocol/valory/contract_api/1.0.0                            | `bafybeidv6wxpjyb2sdyibnmmum45et4zcla6tl63bnol6ztyoqvpl4spmy` | A protocol for contract APIs requests and responses.                                                                       |
| connection/valory/http_client/0.23.0                          | `bafybeidykl4elwbcjkqn32wt5h4h7tlpeqovrcq3c5bcplt6nhpznhgczi` | The HTTP_client connection that wraps a web-based client connecting to a RESTful API specification.                        |
| connection/valory/ledger/0.19.0                               | `bafybeicgfupeudtmvehbwziqfxiz6ztsxr5rxzvalzvsdsspzz73o5fzfi` | A connection to interact with any ledger API and contract API.                                                             |
| connection/valory/p2p_libp2p_client/0.1.0                     | `bafybeidwcobzb7ut3efegoedad7jfckvt2n6prcmd4g7xnkm6hp6aafrva` | The libp2p client connection implements a tcp connection to a running libp2p node as a traffic delegate to send/receive envelopes to/from agents in the DHT. |
